/*
 * AT-SPI - Assistive Technology Service Provider Interface
 * (Gnome Accessibility Project; https://wiki.gnome.org/Accessibility)
 *
 * Copyright (c) 2014 Samsung Electronics Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef MY_ATK_H
#define MY_ATK_H

#include "my-atk-action.h"
#include "my-atk-object.h"
#include "my-atk-component.h"
#include "my-atk-document.h"
#include "my-atk-editable-text.h"
#include "my-atk-hyperlink.h"
#include "my-atk-hypertext.h"
#include "my-atk-image.h"
#include "my-atk-table.h"
#include "my-atk-table-cell.h"
#include "my-atk-text.h"
#include "my-atk-selection.h"
#include "my-atk-value.h"

#endif /*MY_ATK_H*/
